==> dde-daemon_6.0.49.tar.xz: BUILD/misc/ts/org.deepin.dde.accounts.policy/policy_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_HK" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>修改您的用戶數據需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>修改您的用戶數據</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>修改用戶數據需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>管理用戶帳戶</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>開啟自動登錄需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>開啟自動登錄</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>關閉自動登錄需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>關閉自動登錄</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>開啟無密碼登錄需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>開啟無密碼登錄</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>關閉無密碼登錄需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>關閉無密碼登錄</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>設置鍵盤佈局需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>設置鍵盤佈局</translation>
		</message>
	</context>
</TS>

==> dde-daemon_6.1.41.tar.xz: BUILD/misc/ts/org.deepin.dde.accounts.policy/policy_zh_HK.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_HK">
	<context>
		<name>policy</name>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!message" line="0"/>
			<source>Authentication is required to change your own user data</source>
			<translation>修改您的用戶數據需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.change-own-user-data!description" line="0"/>
			<source>Change your own user data</source>
			<translation>修改您的用戶數據</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!message" line="0"/>
			<source>Authentication is required to change user data</source>
			<translation>修改用戶數據需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.user-administration!description" line="0"/>
			<source>Manage user accounts</source>
			<translation>管理用戶帳戶</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!message" line="0"/>
			<source>Authentication is required to enable auto login</source>
			<translation>開啟自動登錄需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-auto-login!description" line="0"/>
			<source>Enable Auto Login</source>
			<translation>開啟自動登錄</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!message" line="0"/>
			<source>Authentication is required to disable auto login</source>
			<translation>關閉自動登錄需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-auto-login!description" line="0"/>
			<source>Disable Auto Login</source>
			<translation>關閉自動登錄</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-quick-login!message" line="0"/>
			<source>Authentication is required to enable quick login</source>
			<translation>開啟快速登錄需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-quick-login!description" line="0"/>
			<source>Enable Quick Login</source>
			<translation>開啟快速登錄</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-quick-login!message" line="0"/>
			<source>Authentication is required to disable quick login</source>
			<translation>關閉快速登錄需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-quick-login!description" line="0"/>
			<source>Disable Quick Login</source>
			<translation>關閉快速登錄</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-wechat-auth!message" line="0"/>
			<source>Authentication is required to enable WeChat code login</source>
			<translation>開啟微信掃碼登錄需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-wechat-auth!description" line="0"/>
			<source>Enable WeChat Code Login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-wechat-auth!message" line="0"/>
			<source>Authentication is required to disable WeChat code login</source>
			<translation>關閉微信掃碼登錄需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-wechat-auth!description" line="0"/>
			<source>Disable WeChat Code Login</source>
			<translation type="unfinished"/>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!message" line="0"/>
			<source>Authentication is required to enable login without password</source>
			<translation>開啟無密碼登錄需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.enable-nopass-login!description" line="0"/>
			<source>Enable Login without password</source>
			<translation>開啟無密碼登錄</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!message" line="0"/>
			<source>Authentication is required to disable login without password</source>
			<translation>關閉無密碼登錄需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.disable-nopass-login!description" line="0"/>
			<source>Disable Login without password</source>
			<translation>關閉無密碼登錄</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!message" line="0"/>
			<source>Authentication is required to set keyboard layout</source>
			<translation>設置鍵盤佈局需要認證</translation>
		</message>
		<message>
			<location filename="org.deepin.dde.accounts.set-keyboard-layout!description" line="0"/>
			<source>Set keyboard layout</source>
			<translation>設置鍵盤佈局</translation>
		</message>
	</context>
</TS>
